/* ConnectorOptions.java

	Purpose:
		
	Description:
		
	History:
		6:04 PM 2022/9/8, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.zhtml.P;

/**
 * Options for the connector in the Series on point feature.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class ConnectorOptions extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		dashstyle,
		stroke,
		width
	}

	/**
	 * Returns a name for the dash style to use for the connector.
	 *
	 * <p>
	 * Defaults to null
	 */
	public String getDashstyle() {
		return getAttr(Attrs.dashstyle, null).asString();
	}

	/**
	 * Returns a name for the dash style to use for the connector.
	 *
	 * <p>
	 * Defaults to null
	 */
	public void setDashstyle(String dashstyle) {
		setAttr(Attrs.dashstyle, dashstyle);
	}

	/**
	 * Returns the color of the connector line. By default it's the series' color.
	 *
	 * <p>
	 * Defaults to null
	 */
	public String getStroke() {
		return getAttr(Attrs.stroke, null).asString();
	}

	/**
	 * Returns the color of the connector line. By default it's the series' color.
	 *
	 * <p>
	 * Defaults to null
	 */
	public void setStroke(String stroke) {
		setAttr(Attrs.stroke, stroke);
	}

	/**
	 * Returns the pixel width of the connector line.
	 *
	 * <p>
	 * Defaults to {@code 1}.
	 */
	public Number getWidth() {
		return getAttr(Attrs.width, 1).asNumber();
	}

	/**
	 * Sets the pixel width of the connector line.
	 *
	 * <p>
	 * Defaults to {@code 1}.
	 * @param width
	 */
	public void setWidth(Number width) {
		setAttr(Attrs.width, width);
	}
}
