/* Level.java

	Purpose:
		
	Description:
		
	History:
		Mon, Nov 09, 2015  3:32:38 PM, Created by Christopher

Copyright (C) 2015 Potix Corporation. All Rights Reserved.

This program is distributed under LGPL Version 2.1 in the hope that
it will be useful, but WITHOUT ANY WARRANTY.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Configure a crosshair that follows either the mouse pointer or the hovered point.
 * 
 * @author Christopher
 */
public class Crosshair extends Optionable{
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		className,
		color,
		dashStyle,
		enabled,
		snap,
		width,
		zIndex
	}

	/**
	 * Returns the class name for the crosshair, especially as a hook for styling.
	 * <p>Default: ""
	 * @since 11.2.0.0
	 */
	public String getClassName() {
		return getAttr(Attrs.className, "").asString();
	}

	/**
	 * Sets the class name for the crosshair, especially as a hook for styling.
	 * @since 11.2.0.0
	 */
	public void setClassName(String className) {
		setAttr(Attrs.className, className);
	}

	/**
	 * The color of the crosshair
	 * <p>
	 * Default: #C0C0C0
	 * @since 2.1.1
	 */
	public Color getColor() {
		return (Color) getAttr(Attrs.color, new Color("#C0C0C0")).asValue();
	}
	/**
	 * The color of the crosshair
	 * @since 2.1.1
	 */
	public void setColor(Color color) {
		setAttr(Attrs.color, color);
	}
	/**
	 * The color of the crosshair
	 * @since 2.1.1
	 */
	public void setColor(String color) {
		setColor(new Color(color));
	}
	/**
	 * The color of the crosshair
	 * @since 2.1.1
	 */
	public void setColor(LinearGradient color) {
		setColor(new Color(color));
	}
	/**
	 * The color of the crosshair
	 * @since 2.1.1
	 */
	public void setColor(RadialGradient color) {
		setColor(new Color(color));
	}
	
	/**
	 * Get the dash style for the crosshair.
	 * <p>
	 * Defaults to "Solid"
	 * @return the dash style
	 * @since 2.1.1
	 */
	public String getDashStyle() {
		return getAttr(Attrs.dashStyle, "Solid").asString();
	}
	/**
	 * Set the dash style for the crosshair.
	 * <p>
	 * Only the following values are allowed:<br/>
	 * <ul>
	 * <li>Solid</li>
	 * <li>ShortDash</li>
	 * <li>ShortDot</li>
	 * <li>ShortDashDot</li>
	 * <li>ShortDashDotDot</li>
	 * <li>Dot</li>
	 * <li>Dash</li>
	 * <li>LongDash</li>
	 * <li>DashDot</li>
	 * <li>LongDashDot</li>
	 * <li>LongDashDotDot</li>
	 * </ul>
	 * @since 2.1.1
	 */
	public void setDashStyle(String dashStyle) {
		if (!("Solid".equals(dashStyle) ||
			"ShortDash".equals(dashStyle) ||
			"ShortDot".equals(dashStyle) ||
			"ShortDashDot".equals(dashStyle) ||
			"ShortDashDotDot".equals(dashStyle) ||
			"Dot".equals(dashStyle) ||
			"Dash".equals(dashStyle) ||
			"LongDash".equals(dashStyle) ||
			"DashDot".equals(dashStyle) ||
			"LongDashDot".equals(dashStyle) ||
			"LongDashDotDot".equals(dashStyle))) {
			throw new IllegalArgumentException("Unsupported dash style: [" + dashStyle + "]");
		}
		setAttr(Attrs.dashStyle, dashStyle, "Solid");
	}

	/**
	 * Returns enable or disable the crosshair.
	 * <p>
	 * Default: null
	 * @since 11.2.0.0
	 */

	public Boolean isEnabled() {
		return getAttr(Attrs.enabled, null).asBoolean();
	}

	/**
	 * Sets enable or disable the crosshair.
	 * <p>
	 * Default: null
	 * @since 11.2.0.0
	 */
	public void setEnabled(Boolean enabled) {
		setAttr(Attrs.enabled, enabled, null);
	}
	
	/**
	 * Get whether the crosshair should snap to the point or follow the pointer
	 * independent of points.
	 * <p>
	 * Defaults to true.
	 * @since 2.1.1
	 */
	public boolean getSnap() {
		return getAttr(Attrs.snap, true).asBoolean();
	}
	/**
	 * Set whether the crosshair should snap to the point or follow the pointer
	 * independent of points.
	 * @since 2.1.1
	 */
	public void setSnap(boolean snap) {
		setAttr(Attrs.snap, snap, true);
	}
	
	/**
	 * Get the pixel width of the crosshair.
	 * <p>
	 * Defaults to 1
	 * @since 2.1.1
	 */
	public Number getWidth() {
		return getAttr(Attrs.width, 1).asNumber();
	}
	/**
	 * Set the pixel width of the crosshair.
	 * @since 2.1.1
	 */
	public void setWidth(Number width) {
		setAttr(Attrs.width, width, 1);
	}
	
	/**
	 * Get the Z index of the crosshair. Higher Z indices allow drawing the
	 * crosshair on top of the series or behind the grid lines.
	 * <p>
	 * Defaults to 2.
	 * @since 2.1.1
	 */
	public Number getZIndex() {
		return getAttr(Attrs.zIndex, 2).asNumber();
	}
	
	/**
	 * Set the Z index of the crosshair. Higher Z indices allow drawing the
	 * crosshair on top of the series or behind the grid lines.
	 * @since 2.1.1
	 */
	public void setZIndex(Number zIndex) {
		setAttr(Attrs.zIndex, zIndex, 2);
	}
}
