package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A Halo options
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author hanhsu
 */
public class Halo extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		attributes, opacity, size
	}
	
	/**
	 * Returns the attribute of a Halo options
	 * <p>
	 * Default: an instance of {@link HaloAttributes}.
	 */
	public HaloAttributes getHaloAttributes() {
		HaloAttributes attributes = (HaloAttributes) getAttr(Attrs.attributes);
		if (attributes == null) {
			attributes = new HaloAttributes();
			setHaloAttributes(attributes);
		}
		return attributes;
	}
	
	/**
	 * Sets the attribute of a Halo options
	 * @param attributes
	 *            The attribute of a Halo options
	 */
	public void setHaloAttributes(HaloAttributes attributes) {
		setAttr(Attrs.attributes, attributes);
	}
	
	/**
	 * Returns the opacity for the halo.
	 * <p>
	 * Default: 0.25.
	 */
	public Number getOpacity() {
		return getAttr(Attrs.opacity, 0.25).asNumber();
	}

	/**
	 * Sets the opacity for the halo.
	 * 
	 * @param opacity
	 *            The opacity for the halo. Defaults to 0.25.
	 */
	public void setOpacity(Number opacity) {
		setAttr(Attrs.opacity, opacity, 0.25);
	}
	
	/**
	 * Returns the pixel size of the halo. For point markers this is the radius of the halo. For pie slices it is the width of the halo outside the slice.
	 * For bubbles it is the width of the halo outside the bubble.
	 * <p>
	 * Default: null.
	 */
	public Number getSize() {
		return getAttr(Attrs.size, null).asNumber();
	}

	/**
	 * Sets the pixel size of the halo. For point markers this is the radius of the halo. For pie slices it is the width of the halo outside the slice.
	 * For bubbles it is the width of the halo outside the bubble.
	 * 
	 * @param size
	 *            the pixel size of the halo. For point markers this is the radius of the halo. For pie slices it is the width of the halo outside the slice.
	 * 			  For bubbles it is the width of the halo outside the bubble.
	 */
	public void setSize(Number size) {
		setAttr(Attrs.size, size, null);
	}
}
