package org.zkoss.chart;

import org.zkoss.chart.util.AnyVal;
import org.zkoss.chart.util.DynamicalAttribute;


/**
 * A Halo attributes options
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author hanhsu
 */
public class HaloAttributes extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		fill, stroke
	}
	
	/**
	 * Returns the color of the fill attribute in a Halo options
	 * <p>
	 * Default: #C0C0C0.
	 */
	public Color getFillColor() {
		if (!containsKey(Attrs.fill)) {
			setFillColor("#C0C0C0");
		}
		return (Color) getAttr(Attrs.fill);
	}

	/**
	 * Sets the color of the fill attribute in a Halo options
	 */
	public void setFillColor(Color color) {
		setAttr(Attrs.fill, color, NOT_NULL_VALUE);
	}

	/**
	 * Sets the color of the fill attribute in a Halo options
	 */
	public void setFillColor(String color) {
		setFillColor(new Color(color));
	}

	/**
	 * Sets the color of the fill attribute in a Halo options
	 */
	public void setFillColor(LinearGradient color) {
		setFillColor(new Color(color));
	}

	/**
	 * Sets the color of the fill attribute in a Halo options
	 */
	public void setFillColor(RadialGradient color) {
		setFillColor(new Color(color));
	}
	
	/**
	 * Returns the stroke color attribute in a Halo options
	 * <p>
	 * Default: #C0C0C0.
	 */
	public Color getStrokeColor() {
		if (!containsKey(Attrs.stroke)) {
			setStrokeColor("#C0C0C0");
		}
		return (Color) getAttr(Attrs.stroke);
	}

	/**
	 * Sets the stroke color attribute in a Halo options
	 */
	public void setStrokeColor(Color color) {
		setAttr(Attrs.stroke, color, NOT_NULL_VALUE);
	}

	/**
	 * Sets the stroke color attribute in a Halo options
	 */
	public void setStrokeColor(String color) {
		setStrokeColor(new Color(color));
	}

	/**
	 * Sets the stroke color attribute in a Halo options
	 */
	public void setStrokeColor(LinearGradient color) {
		setStrokeColor(new Color(color));
	}

	/**
	 * Sets the color of the fill attribute in a Halo options
	 */
	public void setStrokeColor(RadialGradient color) {
		setStrokeColor(new Color(color));
	}
	
	public Number getStrokeWidth() {
		return (Number) getExtraAttr("stroke-width");
	}
	
	public void setStrokeWidth(Number strokeWidth) {
		addExtraAttr("stroke-width", new AnyVal<Number>(strokeWidth));
	}
}
