/* Highpass.java

        Purpose:
                
        Description:
                
        History:
                Thu Oct 05 18:38:46 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Mapping options for the highpass filter.
 * <p>A highpass filter lets high frequencies through,
 * but stops low frequencies, making the sound thinner.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class Highpass extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		frequency,
		resonance
	}

	/**
	 * Returns the Frequency or Number or String object of frequency, depend on what was set.
	 * <p>Map to filter frequency in Hertz from 1 to 20,000Hz.
	 * <p>Frequency in Hertz of notes. Overrides pitch mapping if set.
	 */
	public Object getFrequency() {
		Object frequency = this.getAttr(Attrs.frequency);
		if (frequency == null) {
			frequency = new Frequency();
			setFrequency((Frequency) frequency);
		}
		return frequency;
	}

	/**
	 * Sets the Frequency object of frequency.
	 * <p>Map to filter frequency in Hertz from 1 to 20,000Hz.
	 * <p>Frequency in Hertz of notes. Overrides pitch mapping if set.
	 */
	public void setFrequency(Frequency frequency) {
		setAttr(Attrs.frequency, frequency);
	}

	/**
	 * Sets the Number object of frequency.
	 * <p>Map to filter frequency in Hertz from 1 to 20,000Hz.
	 * <p>Frequency in Hertz of notes. Overrides pitch mapping if set.
	 */
	public void setFrequency(Number frequency) {
		setAttr(Attrs.frequency, frequency);
	}

	/**
	 * Sets the String object of frequency.
	 * <p>Map to filter frequency in Hertz from 1 to 20,000Hz.
	 * <p>Frequency in Hertz of notes. Overrides pitch mapping if set.
	 */
	public void setFrequency(String frequency) {
		setAttr(Attrs.frequency, frequency);
	}

	/**
	 * Returns the Resonance or Number or String object, depend on what was set.
	 * <p>Map to filter resonance in dB. Can be negative to cause a dip, or positive to cause a bump.
	 */
	public Object getResonance() {
		Object resonance = this.getAttr(Attrs.resonance);
		if (resonance == null) {
			resonance = new Resonance();
			setResonance((Resonance) resonance);
		}
		return resonance;
	}

	/**
	 * Sets the Resonance object of resonance.
	 * <p>Map to filter resonance in dB. Can be negative to cause a dip, or positive to cause a bump.
	 */
	public void setResonance(Resonance resonance) {
		setAttr(Attrs.resonance, resonance);
	}

	/**
	 * Sets the Number object of resonance.
	 * <p>Map to filter resonance in dB. Can be negative to cause a dip, or positive to cause a bump.
	 */
	public void setResonance(Number resonance) {
		setAttr(Attrs.resonance, resonance);
	}

	/**
	 * Sets the String object of resonance.
	 * <p>Map to filter resonance in dB. Can be negative to cause a dip, or positive to cause a bump.
	 */
	public void setResonance(String resonance) {
		setAttr(Attrs.resonance, resonance);
	}
}
