/* LangChartTypes.java

	Purpose:
		
	Description:
		
	History:
		10:44 AM 2022/9/20, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Chart type description strings. This is added to the chart information region.
 *
 * <p>
 * If there is only a single series type used in the chart, we use the format string
 * for the series type, or default if missing. There is one format string for cases
 * where there is only a single series in the chart, and one for multiple series of the same type.
 *
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LangChartTypes extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		barMultiple,
		barSingle,
		boxplotMultiple,
		boxplotSingle,
		bubbleMultiple,
		bubbleSingle,
		columnMultiple,
		columnSingle,
		combinationChart,
		defaultMultiple,
		defaultSingle,
		emptyChart,
		lineMultiple,
		lineSingle,
		mapTypeDescription,
		pieMultiple,
		pieSingle,
		scatterMultiple,
		scatterSingle,
		splineMultiple,
		splineSingle,
		unknownMap
	}

	/**
	 * <p>Default: {@code "Bar chart with {numSeries} data series."}
	 * @return
	 */
	public String getBarMultiple() {
		return getAttr(Attrs.barMultiple,
				"Bar chart with {numSeries} data series.").asString();
	}

	public void setBarMultiple(String barMultiple) {
		setAttr(Attrs.barMultiple, barMultiple);
	}

	/**
	 * <p>Default: {@code "Bar chart with {numPoints} {#plural(numPoints, bars, bar)}."}
	 */
	public String getBarSingle() {
		return getAttr(Attrs.barSingle, "Bar chart with {numPoints} {#plural(numPoints, bars, bar)}.").asString();
	}

	public void setBarSingle(String barSingle) {
		setAttr(Attrs.barSingle, barSingle);
	}

	/**
	 * <p>Default: {@code "Boxplot with {numSeries} data series."}
	 */
	public String getBoxplotMultiple() {
		return getAttr(Attrs.boxplotMultiple,
				"Boxplot with {numSeries} data series.").asString();
	}

	public void setBoxplotMultiple(String boxplotMultiple) {
		setAttr(Attrs.boxplotMultiple, boxplotMultiple);
	}


	/**
	 * <p>Default: {@code "Boxplot with {numPoints} {#plural(numPoints, boxes, box)}."}
	 */
	public String getBoxplotSingle() {
		return getAttr(Attrs.boxplotSingle,
				"Boxplot with {numPoints} {#plural(numPoints, boxes, box)}.").asString();
	}

	public void setBoxplotSingle(String boxplotSingle) {
		setAttr(Attrs.boxplotSingle, boxplotSingle);
	}

	/**
	 * <p>Default: {@code "Bubble chart with {numSeries} data series."}
	 */
	public String getBubbleMultiple() {
		return getAttr(Attrs.bubbleMultiple,
				"Bubble chart with {numSeries} data series.").asString();
	}

	public void setBubbleMultiple(String bubbleMultiple) {
		setAttr(Attrs.bubbleMultiple, bubbleMultiple);
	}

	/**
	 * <p>Default: {@code "Bubble chart with {numPoints} {#plural(numPoints, bubbles, bubble)}."}
	 */
	public String getBubbleSingle() {
		return getAttr(Attrs.bubbleSingle, "Bubble chart with {numPoints} {#plural(numPoints, bubbles, bubble)}.").asString();
	}

	public void setBubbleSingle(String bubbleSingle) {
		setAttr(Attrs.bubbleSingle, bubbleSingle);
	}


	/**
	 * <p>Default: {@code "Bar chart with {numSeries} data series."}
	 */
	public String getColumnMultiple() {
		return getAttr(Attrs.columnMultiple,
				"Bar chart with {numSeries} data series.").asString();
	}

	public void setColumnMultiple(String columnMultiple) {
		setAttr(Attrs.columnMultiple, columnMultiple);
	}

	/**
	 * <p>Default: {@code "Bar chart with {numPoints} {#plural(numPoints, bars, bar)}."}
	 */
	public String getColumnSingle() {
		return getAttr(Attrs.columnSingle,"Bar chart with {numPoints} {#plural(numPoints, bars, bar)}.").asString();
	}

	public void setColumnSingle(String columnSingle) {
		setAttr(Attrs.columnSingle, columnSingle);
	}

	/**
	 * <p>Default: {@code "Combination chart with {numSeries} data series."}
	 */
	public String getCombinationChart() {
		return getAttr(Attrs.combinationChart,
				"Combination chart with {numSeries} data series.").asString();
	}

	public void setCombinationChart(String combinationChart) {
		setAttr(Attrs.combinationChart, combinationChart);
	}

	/**
	 * <p>Default: {@code "Chart with {numSeries} data series."}
	 */
	public String getDefaultMultiple() {
		return getAttr(Attrs.defaultMultiple,
				"Chart with {numSeries} data series.").asString();
	}

	public void setDefaultMultiple(String defaultMultiple) {
		setAttr(Attrs.defaultMultiple, defaultMultiple);
	}

	/**
	 * <p>Default: {@code "Chart with {numPoints} data {#plural(numPoints, points, point)}."}
	 */
	public String getDefaultSingle() {
		return getAttr(Attrs.defaultSingle,
				"Chart with {numPoints} data {#plural(numPoints, points, point)}.").asString();
	}

	public void setDefaultSingle(String defaultSingle) {
		setAttr(Attrs.defaultSingle, defaultSingle);
	}

	/**
	 * <p>Default: {@code "Empty chart"}
	 */
	public String getEmptyChart() {
		return getAttr(Attrs.emptyChart, "Empty chart").asString();
	}

	public void setEmptyChart(String emptyChart) {
		setAttr(Attrs.emptyChart, emptyChart);
	}

	/**
	 * <p>Default: {@code "Line chart with {numSeries} lines."}
	 */
	public String getLineMultiple() {
		return getAttr(Attrs.lineMultiple, "Line chart with {numSeries} lines.").asString();
	}

	public void setLineMultiple(String lineMultiple) {
		setAttr(Attrs.lineMultiple, lineMultiple);
	}

	/**
	 * <p>Default: {@code "Line chart with {numPoints} data {#plural(numPoints, points, point)}."}
	 */
	public String getLineSingle() {
		return getAttr(Attrs.lineSingle, "Line chart with {numPoints} data {#plural(numPoints, points, point)}.").asString();
	}

	public void setLineSingle(String lineSingle) {
		setAttr(Attrs.lineSingle, lineSingle);
	}

	/**
	 * <p>Default: {@code "Map of {mapTitle} with {numSeries} data series."}
	 */
	public String getMapTypeDescription() {
		return getAttr(Attrs.mapTypeDescription, "Map of {mapTitle} with {numSeries} data series.").asString();
	}

	public void setMapTypeDescription(String mapTypeDescription) {
		setAttr(Attrs.mapTypeDescription, mapTypeDescription);
	}

	/**
	 * <p>Default: {@code "Pie chart with {numSeries} pies."}
	 */
	public String getPieMultiple() {
		return getAttr(Attrs.pieMultiple, "Pie chart with {numSeries} pies.").asString();
	}

	public void setPieMultiple(String pieMultiple) {
		setAttr(Attrs.pieMultiple, pieMultiple);
	}

	/**
	 * <p>Default: {@code "Pie chart with {numPoints} {#plural(numPoints, slices, slice)}."}
	 */
	public String getPieSingle() {
		return getAttr(Attrs.pieSingle, "Pie chart with {numPoints} {#plural(numPoints, slices, slice)}.").asString();
	}

	public void setPieSingle(String pieSingle) {
		setAttr(Attrs.pieSingle, pieSingle);
	}

	/**
	 * <p>Default: {@code "Scatter chart with {numSeries} data series."}
	 */
	public String getScatterMultiple() {
		return getAttr(Attrs.scatterMultiple,
				"Scatter chart with {numSeries} data series.").asString();
	}

	public void setScatterMultiple(String scatterMultiple) {
		setAttr(Attrs.scatterMultiple, scatterMultiple);
	}

	/**
	 * <p>Default: {@code "Scatter chart with {numPoints} {#plural(numPoints, points, point)}."}
	 */
	public String getScatterSingle() {
		return getAttr(Attrs.scatterSingle, "Scatter chart with {numPoints} {#plural(numPoints, points, point)}.").asString();
	}

	public void setScatterSingle(String scatterSingle) {
		setAttr(Attrs.scatterSingle, scatterSingle);
	}

	/**
	 * <p>Default: {@code "Line chart with {numSeries} lines."}
	 */
	public String getSplineMultiple() {
		return getAttr(Attrs.splineMultiple,
				"Line chart with {numSeries} lines.").asString();
	}

	public void setSplineMultiple(String splineMultiple) {
		setAttr(Attrs.splineMultiple, splineMultiple);
	}

	/**
	 * <p>Default: {@code "Line chart with {numPoints} data {#plural(numPoints, points, point)}."}
	 */
	public String getSplineSingle() {
		return getAttr(Attrs.splineSingle, "Line chart with {numPoints} data {#plural(numPoints, points, point)}.").asString();
	}

	public void setSplineSingle(String splineSingle) {
		setAttr(Attrs.splineSingle, splineSingle);
	}

	/**
	 * <p>Default: {@code "Map of unspecified region with {numSeries} data series."}
	 */
	public String getUnknownMap() {
		return getAttr(Attrs.unknownMap,
				"Map of unspecified region with {numSeries} data series.").asString();
	}

	public void setUnknownMap(String unknownMap) {
		setAttr(Attrs.unknownMap, unknownMap);
	}
}
