/* MenuItem.java

	Purpose:
		
	Description:
		
	History:
		Wed, Oct 14, 2015 11:46:02 AM, Created by Christopher

Copyright (C) 2015 Potix Corporation. All Rights Reserved.

This program is distributed under LGPL Version 2.1 in the hope that
it will be useful, but WITHOUT ANY WARRANTY.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.json.JavaScriptValue;

/**
 * 
 * @author Christopher
 */
public class MenuItem extends Optionable {
	private static final long serialVersionUID = -3742432549428441988L;

	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		text, textKey, onclick
	}
	
	/**
	 * Get the text associated with this menu item.
	 * <p>
	 * Default: null
	 * @return text the text value
	 */
	public String getText() {
		return getAttr(Attrs.text, null).asString();
	}
	
	/**
	 * Set the text to be associated with this menu item.
	 * @param text the text to display
	 */
	public void setText(String text) {
		setAttr(Attrs.text, text);
	}

	/**
	 * Get the key to a language string, if internationalization is required.
	 * <p>
	 * Default: null
	 * @since 7.2.2.0
	 */
	public String getTextKey() {
		return getAttr(Attrs.textKey, null).asString();
	}

	/**
	 * Set the key to a language string, if internationalization is required.
	 * @since 7.2.2.0
	 */
	public void setTextKey(String textKey) {
		setAttr(Attrs.textKey, textKey);
	}

	/**
	 * Get the javascript function associated with this menu item's onclick event.
	 * <p>
	 * Default: null
	 */
	public JavaScriptValue getOnclick() {
		return (JavaScriptValue) getAttr(Attrs.onclick, null).asValue();
	}
	
	/**
	 * Set the javascript function to handle this menu item's onclick event.
	 * @param onclick the javascript function to be associated with onclick event
	 */
	public void setOnclick(JavaScriptValue onclick) {
		setAttr(Attrs.onclick, onclick);
	}
}
