/* RadialGradient.java

	Purpose:
		
	Description:
		
	History:
		Thu, Feb 06, 2014 11:29:47 AM, Created by RaymondChao

Copyright (C) 2014 Potix Corporation. All Rights Reserved.

 */
package org.zkoss.chart;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.json.JSONArray;
import org.zkoss.json.JSONObject;
import org.zkoss.lang.Generics;

/**
 * A radial gradient is a smooth transition from one color to another. In
 * addition, several color transitions can be applied to the same element.
 * 
 * <p> All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author jumperchen
 * @author RaymondChao
 */
public class RadialGradient extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		radialGradient, stops
	}

	/**
	 * The cx, cy and r attributes define the outermost circle
	 */
	public RadialGradient(double cx, double cy, double r) {
		JSONObject json = new JSONObject();
		json.put("cx", cx);
		json.put("cy", cy);
		json.put("r", r);
		setAttr(Attrs.radialGradient, json);
	}

	/**
	 * Adds the color range for a gradient can be composed of two or more colors.
	 * Each color is specified with a offset in order.
	 */
	public void addStop(double index, String color) {
		List<Stop> stops = Generics.cast(getAttr(Attrs.stops, null).asValue());
		if (stops == null) {
			stops = new ArrayList<Stop>();
		}
		stops.add(new Stop(index, color));
		setAttr(Attrs.stops, stops);
	}
	
	/**
	 * Sets the color range for a gradient can be composed of two colors.
	 * It is the same as<br/>
	 * <pre><code>
	 * setStops(Arrays.asList(new Stop(0, color1), new Stop(1, color2)));
	 * </code></pre>
	 *
	 * @see #setStops(Stop... stops)
	 */
	public void setStops(String color1, String color2) {
		setStops(new Stop(0, color1), new Stop(1, color2));
	}

	/**
	 * Sets the color range for a gradient can be composed of two or more colors.
	 * Each color is specified with a offset in order.
	 * <p>
	 * For example,
	 * <pre><code>
	 * setStops(Arrays.asList(new Stop[]{
	 *     new Stop(0, "rgb(255, 255, 255)"),
	 *     new Stop(1, "rgb(200, 200, 255)")
	 * }));
	 * </code></pre>
	 */
	public void setStops(List<Stop> stops) {
		setAttr(Attrs.stops, stops);
	}

	/**
	 * Sets the color range for a gradient can be composed of two or more colors.
	 * Each color is specified with a offset in order.
	 * <p>
	 * For example,
	 * <pre><code>
	 * setStops(
	 *     new Stop(0, "rgb(255, 255, 255)"),
	 *     new Stop(1, "rgb(200, 200, 255)")
	 * );
	 * </code></pre>
	 */
	public void setStops(Stop... stops) {
		setStops(Arrays.asList(stops));
	}

	/**
	 * Returns the all stops
	 */
	public List<Stop> getStops() {
		return Generics.cast(getAttr(Attrs.stops, null).asValue());
	}
}