/* StackShadow.java

        Purpose:
                
        Description:
                
        History:
                Thu Oct 19 18:29:29 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.plotOptions.TargetOptions;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 *
 * Relevant only for pictorial series.
 * The stackShadow forms the background of stacked points.
 * Requires series.stacking to be defined.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class StackShadow extends Optionable {
    private enum Attrs implements PlotAttribute, DynamicalAttribute {
        borderColor,
        borderWidth,
        color,
        enabled
    }

    /**
     * Returns the color of the stackShadow border.
     * <p>
     * Default: "transparent"
     */
    public Color getBorderColor() {
        return (Color) getAttr(Attrs.borderColor, "transparent").asValue();
    }

    /**
     * Sets the color of the stackShadow border.
     */
    public void setBorderColor(Color borderColor) {
        setAttr(Attrs.borderColor, borderColor);
    }

    /**
     * Sets the color of the stackShadow border.
     */
    public void setBorderColor(String borderColor) {
        setColor(new Color(borderColor));
    }

    /**
     * Sets the color of the stackShadow border.
     */
    public void setBorderColor(LinearGradient borderColor) {
        setColor(new Color(borderColor));
    }

    /**
     * Sets the color of the stackShadow border.
     */
    public void setBorderColor(RadialGradient borderColor) {
        setBorderColor(new Color(borderColor));
    }

    /**
     * Returns the width of the stackShadow border.
     * <p>Defaults: 0
     */
    public Number getBorderWidth() {
        return getAttr(Attrs.borderWidth, 0).asNumber();
    }

    /**
     * Sets the width of the stackShadow border.
     */
    public void setBorderWidth(Number borderWidth) {
        setAttr(Attrs.borderWidth, borderWidth);
    }

    /**
     * Returns the color of the stackShadow.
     * <p>
     * Default: "#dedede"
     */
    public Color getColor() {
        return (Color) getAttr(Attrs.color, "#dedede").asValue();
    }

    /**
     * Sets the color of the stackShadow.
     */
    public void setColor(Color color) {
        setAttr(Attrs.color, color);
    }

    /**
     * Sets the color of the stackShadow.
     */
    public void setColor(String color) {
        setColor(new Color(color));
    }

    /**
     * Sets the color of the stackShadow.
     */
    public void setColor(LinearGradient color) {
        setColor(new Color(color));
    }

    /**
     * Sets the color of the stackShadow.
     */
    public void setColor(RadialGradient color) {
        setColor(new Color(color));
    }

    /**
     * Returns enable or disable stackShadow.
     * <p>Defaults: null
     */
    public boolean isEnabled() {
        return getAttr(Attrs.enabled, null).asBoolean();
    }

    /**
     * Sets enable or disable stackShadow.
     */
    public void setEnabled(boolean enabled) {
        setAttr(Attrs.enabled, enabled);
    }
}
