/* Tremolo.java

        Purpose:
                
        Description:
                
        History:
                Tue Sep 19 18:02:11 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Mapping options for tremolo effects.
 * <p>Tremolo is repeated changes of volume over time.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class Tremolo extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		depth,
		speed
	}

	/**
	 * Returns the Depth or Number or String object of depth, depend on what was set.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the intensity of the tremolo effect, how much the volume changes.
	 */
	public Object getDepth() {
		Object depth = this.getAttr(Attrs.depth);
		if (depth == null) {
			depth = new Depth();
			setDepth((Depth) depth);
		}
		return depth;
	}

	/**
	 * Sets the Depth object of depth.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the intensity of the tremolo effect, how much the volume changes.
	 */
	public void setDepth(Depth depth) {
		setAttr(Attrs.depth, depth);
	}

	/**
	 * Sets the Number object of depth.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the intensity of the tremolo effect, how much the volume changes.
	 */
	public void setDepth(Number depth) {
		setAttr(Attrs.depth, depth);
	}

	/**
	 * Sets the String object of depth.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the intensity of the tremolo effect, how much the volume changes.
	 */
	public void setDepth(String depth) {
		setAttr(Attrs.depth, depth);
	}

	/**
	 * Returns the Speed or Number or String object of speed, depend on what was set.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the speed of the tremolo effect, how fast the volume changes.
	 */
	public Object getSpeed() {
		Object speed = this.getAttr(Attrs.speed);
		if (speed == null) {
			speed = new Speed();
			setSpeed((Speed) speed);
		}
		return speed;
	}

	/**
	 * Sets the Speed object of speed.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the speed of the tremolo effect, how fast the volume changes.
	 */
	public void setSpeed(Speed speed) {
		setAttr(Attrs.speed, speed);
	}

	/**
	 * Sets the Number object of speed.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the speed of the tremolo effect, how fast the volume changes.
	 */
	public void setSpeed(Number speed) {
		setAttr(Attrs.speed, speed);
	}

	/**
	 * Sets the String object of speed.
	 * <p>Map to tremolo depth, from 0 to 1.
	 * <p>This determines the speed of the tremolo effect, how fast the volume changes.
	 */
	public void setSpeed(String speed) {
		setAttr(Attrs.speed, speed);
	}
}
