package org.zkoss.chart.options3D;

import org.zkoss.chart.Color;
import org.zkoss.chart.LinearGradient;
import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.RadialGradient;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A panel of the 3Dframe around 3D charts
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author hanhsu
 */
public class Panel3D extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		color, size, visible
	}
	
	/**
	 * Returns the color of the panel. Defaults to transparent
	 * <p>
	 * Default: "transparent".
	 */
	public String getColor() {
		if (!containsKey(Attrs.color)) {
			setColor("transparent");
		}
		return getAttr(Attrs.color, "transparent").asString();
	}
	
	/**
	 * Sets the color of the panel.
	 * @param color
	 *            the color of the panel
	 */
	public void setColor(Color color) {
		setAttr(Attrs.color, color, "transparent");
	}
	
	/**
	 * Sets the color of the panel.
	 * @param color
	 *            the color of the panel
	 */
	public void setColor(String color) {
		setAttr(Attrs.color, color, "transparent");
	}

	/**
	 * Sets the color of the panel.
	 * @param color
	 *            the color of the panel
	 */
	public void setColor(LinearGradient color) {
		setColor(new Color(color));
	}

	/**
	 * Sets the color of the panel.
	 * @param color
	 *            the color of the panel
	 */
	public void setColor(RadialGradient color) {
		setColor(new Color(color));
	}
	
	/**
	 * Returns the thickness of the panel. Defaults to 1.
	 * <p>
	 * Default: 1.
	 */
	public Number getSize() {
		return getAttr(Attrs.size, null).asNumber();
	}

	/**
	 * Sets the total the thickness of the panel.
	 * 
	 * @param size
	 *            the total the thickness of the panel.
	 */
	public void setSize(Number size) {
		setAttr(Attrs.size, size, 1);
	}

	/**
	 * Returns whether to display the frame.
	 * Possible values are true, false, "auto" to display only the frames behind the data,
	 * and "default" to display faces behind the data based on the axis layout, ignoring the point of view.
	 * <p>
	 * Default: "default"
	 * @since 7.2.1.0
	 */
	public Object getVisible() {
		return getAttr(Attrs.visible, "default").asValue();
	}

	/**
	 * Sets whether to display the frame.
	 * @since 7.2.1.0
	 */
	public void setVisible(boolean visible) {
		setAttr(Attrs.visible, visible);
	}

	/**
	 * Sets whether to display the frame.
	 * Possible values are "auto" to display only the frames behind the data,
	 * and "default" to display faces behind the data based on the axis layout, ignoring the point of view.
	 * @since 7.2.1.0
	 */
	public void setVisible(String visible) {
		if (!("default".equals(visible) || "auto".equals(visible)))
			throw new IllegalArgumentException("Unsupported visible: [" + visible +"]");
		setAttr(Attrs.visible, visible);
	}
}
