/* DataLabelsFilter.java

	Purpose:
		
	Description:
		
	History:
		Wed Nov 20 12:17:03 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.Point;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A declarative filter to control of which data labels to display.
 * The declarative filter is designed for use when callback functions are not
 * available, like when the chart options require a pure JSON structure or for
 * use with graphical editors. For programmatic control, use the formatter instead,
 * and return undefined to disable a single data label.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class DataLabelsFilter extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		operator, property, value
	}

	/**
	 * Returns the operator to compare by. Can be one of {@literal >}, {@literal <}, {@literal >}=, {@literal <}=, ==, and ===.
	 * <p>
	 * Default: null
	 */
	public String getOperator() {
		return getAttr(Attrs.operator, null).asString();
	}

	/**
	 * Sets the operator to compare by. Can be one of {@literal >}, {@literal <}, {@literal >}=, {@literal <}=, ==, and ===.
	 */
	public void setOperator(String operator) {
		if (!(">".equals(operator) || "<".equals(operator)
				|| ">=".equals(operator) || "<=".equals(operator)
				|| "==".equals(operator) || "===".equals(operator)))
			throw new IllegalArgumentException("Unsupported operator: [ " + operator + " ]");
		setAttr(Attrs.operator, operator);
	}

	/**
	 * Returns the point property to filter by.
	 * Point options are passed directly to properties, additionally there are
	 * y value, percentage and others listed under {@link Point} members.
	 * <p>
	 * Default: null
	 */
	public String getProperty() {
		return getAttr(Attrs.property, null).asString();
	}

	/**
	 * Sets the point property to filter by.
	 * Point options are passed directly to properties, additionally there are
	 * y value, percentage and others listed under {@link Point} members.
	 */
	public void setProperty(String property) {
		setAttr(Attrs.property, property);
	}

	/**
	 * Returns the value to compare against.
	 * <p>
	 * Default: null
	 */
	public Number getValue() {
		return getAttr(Attrs.value, null).asNumber();
	}

	/**
	 * Sets the value to compare against.
	 */
	public void setValue(Number value) {
		setAttr(Attrs.value, value);
	}
}
