/* NetworkGraphDataLabels.java

	Purpose:
		
	Description:
		
	History:
		Fri Nov 15 12:51:00 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.json.JavaScriptValue;

/**
 * An option of data labels used for networkgraph plot.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class NetworkGraphDataLabels extends DataLabels {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		linkFormat, linkFormatter, linkTextPath
	}

	/**
	 * Returns the format string specifying what to show for links in the networkgraph.
	 * <p>
	 * Default: null
	 */
	public String getLinkFormat() {
		return getAttr(Attrs.linkFormat, null).asString();
	}

	/**
	 * Sets the format string specifying what to show for links in the networkgraph.
	 */
	public void setLinkFormat(String linkFormat) {
		setAttr(Attrs.linkFormat, linkFormat);
	}

	/**
	 * Returns the callback to format data labels for links in the sankey diagram.
	 * The linkFormat option takes precedence over the linkFormatter.
	 */
	public JavaScriptValue getLinkFormatter() {
		return (JavaScriptValue) getAttr(Attrs.linkFormatter);
	}

	/**
	 * Sets the callback to format data labels for links in the sankey diagram.
	 * The linkFormat option takes precedence over the linkFormatter.
	 */
	public void setLinkFormatter(JavaScriptValue linkFormatter) {
		setAttr(Attrs.linkFormatter, linkFormatter);
	}

	/**
	 * Returns the options for a link label text which should follow link connection,
	 * if any. Otherwise, create a new one.
	 * Note: Only SVG-based renderer supports this option.
	 */
	public DataLabelsTextPath getLinkTextPath() {
		DataLabelsTextPath linkTextPath = (DataLabelsTextPath) getAttr(Attrs.linkTextPath);
		if (linkTextPath == null) {
			linkTextPath = new DataLabelsTextPath();
			setLinkTextPath(linkTextPath);
		}
		return linkTextPath;
	}

	/**
	 * Sets the options for a link label text which should follow link connection.
	 * Note: Only SVG-based renderer supports this option.
	 */
	public void setLinkTextPath(DataLabelsTextPath linkTextPath) {
		setAttr(Attrs.linkTextPath, linkTextPath);
	}
}
