/* PackedBubblePlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Wed Nov 20 11:48:15 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for packed bubble plot.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class PackedBubblePlotOptions extends BubblePlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		draggable,
		layoutAlgorithm,
		parentNode,
		useSimulation
	}

	@Override
	protected DataLabels newDataLabels() {
		return new PackedBubbleDataLabels();
	}

	@Override
	public PackedBubbleDataLabels getDataLabels() {
		return (PackedBubbleDataLabels) super.getDataLabels();
	}

	/**
	 * Flag to determine if nodes are draggable or not.
	 * <p>Default: {@code true}
	 * @since 10.2.1.0
	 */
	public boolean isDraggable() {
		return getAttr(Attrs.draggable, true).asBoolean();
	}

	/**
	 * Flag to determine if nodes are draggable or not.
	 * <p>Default: {@code true}
	 * @since 10.2.1.0
	 */
	public void setDraggable(boolean draggable) {
		setAttr(Attrs.draggable, draggable);
	}

	/**
	 * Returns series options for parent nodes.
	 * <p>Default: an instance of {@link PackedBubbleParentNode}
	 * @since 10.2.1.0
	 */
	public PackedBubbleParentNode getParentNode() {
		return (PackedBubbleParentNode) getAttr(Attrs.parentNode, PackedBubbleParentNode.class).asValue();
	}

	/**
	 * Sets series options for parent nodes.
	 * @since 10.2.1.0
	 */
	public void setParentNode(PackedBubbleParentNode parentNode) {
		setAttr(Attrs.parentNode, parentNode);
	}

	/**
	 * Return options for layout algorithm when simulation is enabled, if any. Otherwise, create a new one.
	 */
	public PackedBubbleLayoutAlgorithm getLayoutAlgorithm() {
		PackedBubbleLayoutAlgorithm layoutAlgorithm = (PackedBubbleLayoutAlgorithm) getAttr(Attrs.layoutAlgorithm);
		if (layoutAlgorithm == null) {
			layoutAlgorithm = new PackedBubbleLayoutAlgorithm();
			setLayoutAlgorithm(layoutAlgorithm);
		}
		return layoutAlgorithm;
	}

	/**
	 * Sets options for layout algorithm when simulation is enabled.
	 */
	public void setLayoutAlgorithm(PackedBubbleLayoutAlgorithm layoutAlgorithm) {
		setAttr(Attrs.layoutAlgorithm, layoutAlgorithm);
	}

	/**
	 * Returns an option is giving a possibility to choose between using simulation
	 * for calculating bubble positions.
	 * These reflects in both animation and final position of bubbles.
	 * Simulation is also adding options to the series graph based on used layout.
	 * In case of big data sets, with any performance issues, it is possible to
	 * disable animation and pack bubble in a simple circular way.
	 * <p>
	 * Default: true
	 */
	public boolean isUseSimulation() {
		return getAttr(Attrs.useSimulation, true).asBoolean();
	}

	/**
	 * Sets an option is giving a possibility to choose between using simulation
	 * for calculating bubble positions.
	 * These reflects in both animation and final position of bubbles.
	 * Simulation is also adding options to the series graph based on used layout.
	 * In case of big data sets, with any performance issues, it is possible to
	 * disable animation and pack bubble in a simple circular way.
	 */
	public void setUseSimulation(boolean useSimulation) {
		setAttr(Attrs.useSimulation, useSimulation);
	}
}
