/* TilemapPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Mon Dec 02 17:15:42 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for tilemap plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class TilemapPlotOptions extends HeatmapPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		pointPadding, tileShape
	}

	/**
	 * Returns the padding between points in the tilemap.
	 * <p>
	 * Default: 2
	 */
	public Number getPointPadding() {
		return getAttr(Attrs.pointPadding, 2).asNumber();
	}

	/**
	 * Sets the padding between points in the tilemap.
	 */
	public void setPointPadding(Number pointPadding) {
		setAttr(Attrs.pointPadding, pointPadding);
	}

	/**
	 * Returns the shape of the tiles in the tilemap.
	 * Possible values are {@code hexagon}, {@code circle}, {@code diamond}, and {@code square}.
	 * <p>
	 * Default: "hexagon"
	 */
	public String getTileShape() {
		return getAttr(Attrs.tileShape, "hexagon").asString();
	}

	/**
	 * Sets the shape of the tiles in the tilemap.
	 * Possible values are {@code hexagon}, {@code circle}, {@code diamond}, and {@code square}.
	 */
	public void setTileShape(String tileShape) {
		if (!("hexagon".equals(tileShape) || "circle".equals(tileShape)
				|| "diamond".equals(tileShape) || "square".equals(tileShape)))
			throw new IllegalArgumentException("Unsupported tileShape: [" + tileShape + "]");
		setAttr(Attrs.tileShape, tileShape);
	}
}
