/* TimelinePlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Tue Dec 03 10:25:54 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Chart;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for timeline plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class TimelinePlotOptions extends SeriesPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		ignoreHiddenPoint,
		legendType,
	}

	/**
	 * Returns whether ignore the hidden point.
	 * <p>
	 * Equivalent to {@link Chart#isIgnoreHiddenSeries()}, this option tells
	 * whether the series shall be redrawn as if the hidden point were
	 * <code>null</code>.
	 * <p>
	 * The default value true.
	 * @since 10.2.1.0
	 */
	public boolean isIgnoreHiddenPoint() {
		return getAttr(Attrs.ignoreHiddenPoint, true).asBoolean();
	}

	/**
	 * Sets whether ignore the hidden point.
	 * <p>
	 * Equivalent to {@link Chart#isIgnoreHiddenSeries()}, this option tells
	 * whether the series shall be redrawn as if the hidden point were
	 * <code>null</code>.
	 * <p>
	 * The default value true.
	 * @since 10.2.1.0
	 */
	public void setIgnoreHiddenPoint(boolean ignoreHiddenPoint) {
		setAttr(Attrs.ignoreHiddenPoint, ignoreHiddenPoint);
	}

	/**
	 * Default: "point"
	 */
	public String getLegendType() {
		return getAttr(Attrs.legendType, "point").asString();
	}

	public void setLegendType(String legendType) {
		setAttr(Attrs.legendType, legendType);
	}
}
