/* VariwidePlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Wed Dec 04 16:06:21 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for variwide plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class VariwidePlotOptions extends ColumnPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		groupPadding, // override
		pointPadding // override
	}

	/**
	 * Returns padding between each value groups, in x axis units.
	 * In a variwide chart, the group padding is 0 in order to express the horizontal stacking of items.
	 * <p>Default: 0
	 */
	public Number getGroupPadding() {
		return getAttr(Attrs.groupPadding, 0).asNumber();
	}

	/**
	 * Sets padding between each value groups, in x axis units.
	 */
	public void setGroupPadding(Number groupPadding) {
		setAttr(Attrs.groupPadding, groupPadding);
	}

	/**
	 * Returns padding between each column or bar, in x axis units.
	 * In a variwide chart, the point padding is 0 in order to express the horizontal stacking of items.
	 * <p>Default: 0
	 */
	public Number getPointPadding() {
		return getAttr(Attrs.pointPadding, 0).asNumber();
	}

	/**
	 * Sets padding between each column or bar, in x axis units.
	 */
	public void setPointPadding(Number pointPadding) {
		setAttr(Attrs.pointPadding, pointPadding);
	}
}
