/* Charts.js

	Purpose:

	Description:
		Charts 3.0.9 version
	History:
		Wed, Jan 08, 2014  4:59:20 PM, Created by jumperchen

Copyright (C)  Potix Corporation. All Rights Reserved.
*/
(function () {
	function _maskInfo(wgt, txt) {
		var w = new zul.wgt.Div({
			style: 'color: #EE1111; font-weight: bold; border: 1px solid #C5C5C5',
			children: [new zul.wgt.Label({value: txt})]
		});
		w.replaceHTML('#' + wgt.uuid);
	}
	function _convertGlobalOptions(options, plotData) {
		options = options || {};
		var global = options.global = options.global || {};
		if (!global.VMLRadialGradientURL) {
			global.VMLRadialGradientURL = zk.ajaxURI('web/js/chart/ext/gfx/vml-radial-gradient.png', {au:true});
		}
		if (!global.canvasToolsURL) {
			global.canvasToolsURL = zk.ajaxURI('web/js/chart/ext/modules/canvas-tools.js', {au:true});
		}

		// highcharts use global option to change the chart's style
		// For example - http://jsfiddle.net/gh/get/jquery/1.7.2/highslide-software/highcharts.com/tree/master/samples/highcharts/chart/style-serif-font/
		if (plotData.chart && plotData.chart.style)
			options.chart = {
				style: plotData.chart.style
			};
		return options
	}

	// support plot events
	var PlotEvents = {
			click: {eventName: 'onPlotClick', callback: '_doPlotClick'},
			checkboxClick: {eventName: 'onPlotCheckboxClick', callback: '_doPlotCheckboxClick'},
			legendItemClick: {eventName: 'onPlotLegendItemClick', callback: '_doPlotLegendItemClick'},
			mouseOut: {eventName: 'onPlotMouseOut', callback: '_doPlotMouseOut'},
			mouseOver: {eventName: 'onPlotMouseOver', callback: '_doPlotMouseOver'},
			hide: {eventName: 'onPlotHide', callback: '_doPlotHide'},
			show: {eventName: 'onPlotShow', callback: '_doPlotShow'}
	};

	var DefaultOptions = jq.extend(true, {}, Highcharts.getOptions());
	function resetOptions() {
		var options = Highcharts.getOptions();
		for (var key in options) {
			if (typeof options[key] !== 'function')
				delete options[key];
		}
		Highcharts.setOptions(DefaultOptions);
	}

	// Override Highcharts.js point.select() method referred from Highcharts.js.
	(function (H) {
		var NORMAL_STATE = '',
			SELECT_STATE = 'select',
			pick = H.pick,
			each = jq.each,
			inArray = jq.inArray;

		function decreaseCounter(index, defaultOptions) {
			var length = defaultOptions.length,
				result = index - 1;
			return result < 0 ? length - 1 : result;
		}

		H.wrap(H.Point.prototype, 'select', function (select, selected, accumulate, fromServer) {
			var point = this,
				series = point.series,
				chart = series.chart;

			selected = pick(selected, !point.selected);

			// fire the event with the defalut handler
			// Potix: add fromServer attribute to determine whether to update state to server.
			point.firePointEvent(selected ? 'select' : 'unselect', { accumulate: accumulate, fromServer: fromServer}, function () {
				point.selected = point.options.selected = selected;
				series.options.data[inArray(point, series.data)] = point.options;

				point.setState(selected && SELECT_STATE);

				// unselect all other points unless Ctrl or Cmd + click
				if (!accumulate) {
					each(chart.getSelectedPoints(), function (i, loopPoint) {
						if (loopPoint.selected && loopPoint !== point) {
							loopPoint.selected = loopPoint.options.selected = false;
							series.options.data[inArray(loopPoint, series.data)] = loopPoint.options;
							loopPoint.setState(NORMAL_STATE);
							// Potix: add fromServer attribute to determine whether to update state to server.
							loopPoint.firePointEvent('unselect', {fromServer: fromServer});
						}
					});
				}
			});
		});
		// ZKCHART-4: sync the removed one series color and symbol to the new one
		H.wrap(H.Series.prototype, 'remove', function (remove) {
			var chart = this.chart,
				counters = chart.counters;
			remove.apply(this, [false]); // B-ZKCHARTS-20: Do not redraw the chart when removing series
			// chart.counters is removed in highchart 4.0.4
			// counters.color = decreaseCounter(counters.color, chart.options.colors);
			// counters.symbol = decreaseCounter(counters.symbol, chart.options.symbols);
		});
	} (Highcharts));

	var All_Charts_Type = ['area', 'arearange', 'areaspline', 'areasplinerange',
							'bar', 'boxplot', 'bubble', 'column', 'columnrange',
							'errorbar', 'flame', 'funnel', 'gauge', 'solidgauge', 'line',
							'heatmap', 'pie', 'scatter', 'series', 'spline',
							'waterfall', 'polar', 'pyramid', 'treemap', 'xrange'];

chart.Charts = zk.$extends(zul.Widget, {
	_drilldownLevel: 0,
	$init: function () {
		this.$supers('$init', arguments);
	},
	$define: {
		options: null,
		theme: null,
		series: null,
		_chartLoaded: false
	},
	bind_: function () {
		this.$supers(chart.Charts,'bind_', arguments);
		zWatch.listen({onSize: this});
		var isOnSizeNotMissing = zk.version && zk.version >= '9.0.1.1';
		if (isOnSizeNotMissing && (this._hflex || this._vflex)) // init the chart at onSize when hflex or vflex is set
			return;
		if (this.plotData) {
			// apply the theme options
			if (this._theme) {
				// ZKCHARTS-5: reset to default options except function
				resetOptions();
				if (this._theme != 'DefaultTheme')
					Highcharts.setOptions(this._theme);
			}
			var plotData = this._convertAttrs(this.plotData);
			// should set global options after reset options.
			Highcharts.setOptions(_convertGlobalOptions(this._options, plotData));
			this.engine = this.$class.newEngine(plotData);
			this._chartLoaded = true;
			// highcharts stops using jquery in their code, so events will not go through zk jq now
			// have to manually stops event from passing through charts component or zk jq will receive
			// the redundant click event since it is listening on the document itself
			jq(this.$n()).on('click', this.proxy(function(event) {
				if (event.currentTarget === this.$n()) {
					event.preventDefault();
					event.stopPropagation();
				}
			}));
			// SVG 1.1 doesn't handle keyboard events, so we register a window listener instead
			jq(window).on('keydown', this.proxy(this.captureKeyDown_))
				.on('fullscreenchange', this.proxy(this._onFullscreen))
				.on('webkitfullscreenchange', this.proxy(this._onFullscreen))
				.on('mozfullscreenchange', this.proxy(this._onFullscreen))
				.on('MSFullscreenChange', this.proxy(this._onFullscreen));
		}
	},
	// ZKCHARTS-37: merged duplicate unbind_ definition, also resets _chartLoaded
	unbind_: function () {
		if (this.engine) {
			jq(window).off('MSFullscreenChange', this.proxy(this._onFullscreen))
				.off('mozfullscreenchange', this.proxy(this._onFullscreen))
				.off('webkitfullscreenchange', this.proxy(this._onFullscreen))
				.off('fullscreenchange', this.proxy(this._onFullscreen))
				.off('keydown', this.proxy(this.captureKeyDown_));
			jq(this.$n()).off('click');
			this.engine.destroy();
			this.engine = null;
			this._chartLoaded = false;
		}
		zWatch.unlisten({onSize: this});
		this.$supers(chart.Charts,'unbind_', arguments);
	},
	_onFullscreen: function() {
		var engine = this.engine,
			fullscreenElement = document.fullscreenElement || document.webkitFullscreenElement || document.mozFullScreen || document.msFullscreenElement;
		if (this._fullScreenOpen) {
			engine.setSize(this._originalWidth, this._originalHeight, false);
			this._fullScreenOpen = false;
		} else if (this.$n() == fullscreenElement) {
			this._originalWidth = engine.chartWidth;
			this._originalHeight = engine.chartHeight;
			engine.options.chart.height = null;
			engine.options.chart.width = null;
			this._fullScreenOpen = true;
		}
	},
	onSize: function () {
		this.$supers(chart.Charts, 'onSize', arguments);
		if (this._hflex || this._vflex) {
			if (!this._chartLoaded) {
				if (this.plotData) {
					// apply the theme options
					if (this._theme) {
						// ZKCHARTS-5: reset to default options except function
						resetOptions();
						if (this._theme != 'DefaultTheme')
							Highcharts.setOptions(this._theme);
					}
					var plotData = this._convertAttrs(this.plotData);
					// should set global options after reset options.
					Highcharts.setOptions(_convertGlobalOptions(this._options, plotData));
					this.engine = this.$class.newEngine(plotData);
					this._chartLoaded = true;
					jq(this.$n()).on('click', this.proxy(function(event) {
						event.preventDefault();
						event.stopPropagation();
					}));
				}
			} else {
				var n = this.$n();
				this.engine.setSize(n.clientWidth, n.clientHeight, false);
			}
		}
	},
	// used in PlotData.java
	setEval: function (func) {
		try {
			if (func && func != zk.$void) {
				if (jq.isArray(func)) {
					var self = this;
					jq(func).each(function () {
						this.call(self.engine);
					});
				} else {
					func.call(this.engine);
				}
			}
		} catch (e) {
			zk.error(e);
		}
	},
	// used in PlotData.java
	echo: function (attrId, func) {
		this.fire('dummyEcho', {id: attrId, value: func.apply(this.engine, null)}, {toServer: true});
	},
	// Plot Events
	_doPlotClick: function (evt) {
		var p = evt.point,
			pIndex = p.series.data.indexOf(p), // it may be slow but accurate for XYModel
			sIndex = -1,
			isDrilldown = false,
			drilldowns = this.engine.options.drilldown.series;
			//ZKCHARTS-41: drilldown series are in engine.options.drilldown.series
		if (drilldowns && this._drilldownLevel) {
			for (var i = 0; i < drilldowns.length; i++) {
				if (drilldowns[i].id === p.series.options.id) {
					sIndex = i;
					break;
				}
			}
			isDrilldown = true;
		} else {
			sIndex = this.engine.series.indexOf(p.series);
			isDrilldown = false;
		}
		this.fire('onPlotClick', {sIndex: sIndex,
			pIndex: pIndex, category: p.category || p.name, isDrilldown: isDrilldown});
	},
	_doPlotCheckboxClick: function (evt) {
		this.fire('onPlotCheckboxClick', {sIndex: evt.target.index, checked: evt.checked});
	},
	_doPlotHide: function (evt) {
		this.fire('onPlotHide', {sIndex: evt.target.index});
	},
	_doPlotShow: function (evt) {
		this.fire('onPlotShow', {sIndex: evt.target.index});
	},
	_doPlotLegendItemClick: function (evt) {
		this.fire('onPlotLegendItemClick', {sIndex: evt.target.index});
	},
	_doPlotMouseOut: function (evt) {
		this.fire('onPlotMouseOut', {sIndex: evt.target.index});
	},
	_doPlotMouseOver: function (evt) {
		this.fire('onPlotMouseOver', {sIndex: evt.target.index});
	},
	_doPlotDrillDown: function (evt) {
		if (this.isListen('onPlotDrillDown')) {
			var p = evt.point,
				pIndex = p.series.data.indexOf(p); // it may be slow but accurate for XYModel
			this.fire('onPlotDrillDown', {sIndex: this._drilldownLevel, pIndex: pIndex, category: p.category || p.name});
		}
		this._drilldownLevel++;
	},
	_doPlotDrillUp: function (evt) {
		if (this.isListen('onPlotDrillUp') || this.isListen('onPlotDrillDown')) {
			this.fire('onPlotDrillUp', null, {toServer: true});
		}
		this._drilldownLevel--;
	},
	_doPlotSelect: function (evt) {
		var target = evt.target;
		if (!evt.fromServer) {
			this.fire('onPlotSelect', {sIndex: target.series.index,
				pIndex: target.series.data.indexOf(target)}, {toServer: true});
		}
	},
	_doPlotUnselect: function (evt) {
		var target = evt.target;
		if (!evt.fromServer) {
			this.fire('onPlotUnselect', {sIndex: target.series.index,
				pIndex: target.series.data.indexOf(target)}, {toServer: true});
		}
	},
	_doPlotMouseOverPoint: function (evt) {
		var target = evt.target;
		if (!evt.fromServer) {
			this.fire('onPlotMouseOverPoint', {sIndex: target.series.index,
				pIndex: target.series.data.indexOf(target)});
		}
	},
	_doPlotMouseOutPoint: function (evt) {
		var target = evt.target;
		if (!evt.fromServer) {
			this.fire('onPlotMouseOutPoint', {sIndex: target.series.index,
				pIndex: target.series.data.indexOf(target)});
		}
	},
	_convertPlotOptions: function (plotOptions) {
		if (!plotOptions)
			plotOptions = {};
		var type = this.plotData.chart.type;
		if (!type) {
			type = this.plotData.chart.type = 'line'; // default is line type
		}
		if (!plotOptions[type]) {
			plotOptions[type] = {events: {}};
		}
		if (!plotOptions[type].events)
			plotOptions[type].events = {};

		for (var evt in PlotEvents) {
			if (this.isListen(PlotEvents[evt].eventName, {any: true})) {
				// for Bug ZKCHARTS-8, we need to register for all chart types
				for (var t = All_Charts_Type.length; t--;) {
					var at = All_Charts_Type[t];

					if (!plotOptions[at]) {
						plotOptions[at] = {events: {}};
					}
					if (!plotOptions[at].events)
						plotOptions[at].events = {};

					plotOptions[at].events[evt] = this.proxy(this[PlotEvents[evt].callback]);
				}
			}
		}

		if (!plotOptions['series'])
			plotOptions['series'] = {point: {events: {}}};
		if (!plotOptions['series'].point)
			plotOptions['series'].point = {events: {}};
		if (!plotOptions['series'].point.events)
			plotOptions['series'].point.events = {};

		plotOptions['series'].point.events.select = this.proxy(this._doPlotSelect);
		plotOptions['series'].point.events.unselect = this.proxy(this._doPlotUnselect);
		plotOptions['series'].point.events.mouseOver = this.proxy(this._doPlotMouseOverPoint);
		plotOptions['series'].point.events.mouseOut = this.proxy(this._doPlotMouseOutPoint);

		for (var option in plotOptions) {
			plotOptions[option] = this._convertFunction(plotOptions[option], 'dataLabels', 'formatter');
		}
		return plotOptions;
	},
	_convertChartAttrs: function (chart) {
		if (!chart)
			chart = {};
		chart.renderTo = this.$n();

		for (var k in chart) {
			var val = chart[k];
			switch (k) {
			case 'type':
				if (val == 'polar') // we need to remove it for Highcharts JS
					delete chart[k];
				break;
			}
		}
		chart.className = chart.className ? chart.className + ' ' + this.getZclass() : this.getZclass();

		if (!chart.events)
			chart.events = {};
		if (this.isListen('onClick')) {
			chart.events.click = this.proxy(function (event) {
				this.fireX(new zk.Event(this,'onClick', zk.copy(
				{
					pageX: event.pageX,
					pageY: event.pageY,
					which: event.which
				},
				{
					xAxis: event.xAxis[0].value,
					yAxis: event.yAxis[0].value
				}), {}, event));
			});
		}
		if (this.isListen('onSelection')) {
			chart.events.selection = this.proxy(function (event) {
				if (!event.resetSelection === true) {
					this.fireX(new zk.Event(this,
						'onSelection', {
							// to avoid NPE caused by highcharts #3569 bugfix
							xAxisMin: (event.xAxis[0] ? event.xAxis[0].min : null),
							xAxisMax: (event.xAxis[0] ? event.xAxis[0].max : null),
							yAxisMin: (event.yAxis[0] ? event.yAxis[0].min : null),
							yAxisMax: (event.yAxis[0] ? event.yAxis[0].max : null)
						}, {}, event)
					);
				}
				return !(chart.enableZoomSelection === false);
			});
		}
		//register anyway, but only fire event back to server when client actually registered
		chart.events.drilldown = this.proxy(this._doPlotDrillDown);
		chart.events.drillup = this.proxy(this._doPlotDrillUp);
		// ZKCHARTS-71: ignore options3d if polar=true
		if (chart.polar && chart.options3d && chart.options3d.enabled)
			chart.options3d.enabled = false;
		return chart;
	},
	_convertCreditsAttrs: function (credits) {
		if (!credits)
			credits = {};

		if (credits.enabled == undefined)
			credits.enabled = false; // default disable credits
		return credits;
	},
	_convertAxisAttrs: function (axis) {
		for(var name in axis) {
			axis[name] = this._convertFunction(axis[name], 'labels', 'formatter');
		}
		return axis;
	},
	_convertFunction: function(parent, attr, func) {
		if (parent[attr] && parent[attr][func]) {
			parent[attr][func] =  jq.isFunction(parent[attr][func]) ?
					parent[attr][func] : new Function(parent[attr][func]);
		}
		return parent;
	},
	_convertAttrs: function (attrs) {
		attrs.chart = this._convertChartAttrs(attrs.chart);
		attrs.credits = this._convertCreditsAttrs(attrs.credits);

		attrs = this._convertFunction(attrs, 'legend', 'labelFormatter');
		for(var name in attrs.series) {
			attrs.series[name] = this._convertFunction(attrs.series[name], 'dataLabels', 'formatter');
		}
		attrs = this._convertFunction(attrs, 'tooltip', 'formatter');

		attrs.xAxis = this._convertAxisAttrs(attrs.xAxis);
		attrs.yAxis = this._convertAxisAttrs(attrs.yAxis);

		// call after chart attributes
		attrs.plotOptions = this._convertPlotOptions(attrs.plotOptions);
		return attrs;
	},
	_maskTable: function (txt) {
		_maskInfo(this, txt);
	},
	sendDomEvent: function (evt, element) {
		var data = {};
		if (evt.altKey) data.altKey = true;
		if (evt.ctrlKey) data.ctrlKey = true;
		if (evt.shiftKey) data.shiftKey = true;
		if (evt.metaKey) data.metaKey = true;
		data.which = evt.which || 0;
		data.x = evt.x;
		data.y = evt.y;
		var type = evt.type;
		if (type.startsWith('mouse')) {
			if (type.length > 5)
				type = 'Mouse' + type.charAt(5).toUpperCase() + type.substring(6);
			data.pageX = evt.pageX;
			data.pageY = evt.pageY;
		} else if (type.startsWith('key')) {
			if (type.length > 3)
				type = 'Key' + type.charAt(3).toUpperCase() + type.substring(4);
			data.keyCode = evt.keyCode;
			data.charCode = evt.charCode;
		} else if (type == 'dblclick') {
			data.pageX = evt.pageX;
			data.pageY = evt.pageY;
			type = 'DoubleClick';
		} else {
			if (type == 'click') {
				data.pageX = evt.pageX;
				data.pageY = evt.pageY;
			}
			type = type.charAt(0).toUpperCase() + type.substring(1);
		}
		zAu.send(new zk.Event(this, 'onDomEvent', {
			id: element.options.uuid + ':on' + type,
			name: 'on' + type,
			data: data
		}, {toServer:true}));
	},
	captureKeyDown_: function (e) {
		this.doKeyDown_(jq.Event.zk(e, this));
	},
	toggleSonify: function() {
		this.engine.toggleSonify();
	}
}, {
	newEngine: function (plotData) {
		return new Highcharts.Chart(plotData);
	}
});
})();

//ZKCHARTS-42: avoid using iframe for submit form on ios
if (!zk.ios) {
	// Bug ZKCHARTS-6 with Highchart 3.0.9 version
	// Drop-in fix for running the export in an iframe
	Highcharts.wrap(Highcharts, 'post', function (proceed, url, data, formAttributes) {
	    if (!Highcharts.$exportFrame) {
	        Highcharts.$exportFrame =
	            $('<iframe id="hc-export-frame" style="display:none">').appendTo(document.body);
	    }
	    formAttributes = Highcharts.merge({ target: 'hc-export-frame' }, formAttributes);
	    proceed.call(this, url, data, formAttributes);
	});
}
